<template>
    <section class="games">
        <GameSwitch page="dice" />
        <div class="games__row">
            <div class="dice">
                <div class="dice__row">
                    <div class="dice__col">
                        <label for="sum" class="dice__label">Сумма</label>
                        <div class="dice__group">
                            <input
                                class="dice__amount"
                                type="number"
                                min="1"
                                max="99999"
                                step="1"
                                v-model="bet"
                            />
                            <button type="button" class="dice__btn" @click="typeBet('min')">
                                Min
                            </button>
                            <button type="button" class="dice__btn" @click="typeBet('max')">
                                Max
                            </button>
                            <button type="button" class="dice__btn" @click="typeBet('x2')">
                                X2
                            </button>
                            <button type="button" class="dice__btn" @click="typeBet('/2')">
                                /2
                            </button>
                        </div>
                    </div>
                    <div class="dice__col">
                        <div class="dice__win">
                            <div class="dice__win-amount">
                                <IOdometer
                                    class="IOdometer"
                                    :value="result"
                                />
                            </div>
                            <div class="dice__label dice__label_normal">
                                Возможный выигрыш
                            </div>
                        </div>
                    </div>
                    <div class="dice__col">
                        <label for="chance" class="dice__label">Шанс</label>
                        <div class="dice__group">
                            <input
                                class="dice__amount"
                                type="number"
                                min="1"
                                max="95"
                                step="1"
                                v-model="chance"
                            />
                            <button type="button" class="dice__btn" @click="typeChance('min')">
                                Min
                            </button>
                            <button type="button" class="dice__btn" @click="typeChance('max')">
                                Max
                            </button>
                            <button type="button" class="dice__btn" @click="typeChance('x2')">
                                X2
                            </button>
                            <button type="button" class="dice__btn" @click="typeChance('/2')">
                                /2
                            </button>
                        </div>
                    </div>
                    <div class="dice__col dice__col_3-cols">
                        <div class="dice__distance">
                            {{ minRange.min }} - {{ minRange.max }}
                        </div>
                        <button type="button" class="dice__btn-range" @click="createBet('min')" @keypress.enter.prevent>
                            Меньше
                        </button>
                    </div>
                    <div class="dice__col dice__col_3-cols">
                        <div class="dice__distance">
                            {{ middleRange.min }} - {{ middleRange.max }}
                        </div>
                        <button type="button" class="dice__btn-range" @click="createBet('middle')" @keypress.enter.prevent>
                            Середина
                        </button>
                    </div>
                    <div class="dice__col dice__col_3-cols">
                        <div class="dice__distance">
                            {{ maxRange.min }} - {{ maxRange.max }}
                        </div>
                        <button type="button" class="dice__btn-range" @click="createBet('max')" @keypress.enter.prevent>
                            Больше
                        </button>
                    </div>
                    <div
                        class="dice__col dice__col_3-cols"
                        style="margin: auto;margin-top:10px;justify-content: center;display: flex;flex: 0 0 100%"
                        v-if="loader"
                    >
                        <div class="cssload-loader">
                            <div class="cssload-inner cssload-one"></div>
                            <div class="cssload-inner cssload-two"></div>
                            <div class="cssload-inner cssload-three"></div>
                        </div>
                    </div>
                    <div
                        class="dice__message mt-2"
                        :class="message.type"
                        v-html="message.text"
                    >
                    </div>
                </div>
            </div>
            <History />
        </div>
    </section>
</template>

<script>
import GameSwitch from '../components/GameSwitch'
import History from '../components/History'
import IOdometer from 'vue-odometer'

import 'odometer/themes/odometer-theme-default.css'

export default {
    components: {
        GameSwitch,
        History,
        IOdometer
    },
    data () {
        return {
            bet: 1,
            chance: 80,
            result: 1.25,
            loader: false,
            minRange: {
                min: 0,
                max: 799999
            },
            middleRange: {
                min: 100000,
                max: 899999
            },
            maxRange: {
                min: 200000,
                max: 999999
            },
            message: {
                type: null,
                text: null
            }
        }
    },
    methods: {
        createBet(type) {
            this.message = { type: null, text: null }
            this.loader = true;
            this.$root.axios.post('/dice/bet', {
                amount: this.bet,
                chance: this.chance,
                type: type
            })
            .then(response => {
                this.loader = false;
                const { data } = response;

                if(typeof data.error == 'undefined') {
                    this.$root.user.balance = data.balance;
                    this.message = {
                        type: data.status == true ? 'success' : 'error',
                        text: data.text
                    }
                    return;
                }

                this.message = {
                    type: 'error',
                    text: data.message
                }

            })
            .catch(error => {
                this.loader = false;
                this.message = {
                    type: 'error',
                    text: error.response.data.message
                }
            })
        },
        typeBet(type) {
            switch (type) {
                case "max":
                    this.bet = this.$root.user !== null ? this.$root.user.balance : 0;
                break;
                case "min":
                    this.bet = 1;
                break;
                case "x2":
                    this.bet = (this.bet * 2).toFixed(2);
                break;
                case "/2":
                    this.bet = (this.bet / 2).toFixed(2);
                break;
            }
        },
        typeChance(type) {
            switch (type) {
                case "max":
                    this.chance = 95;
                break;
                case "min":
                    this.chance = 1;
                break;
                case "x2":
                    this.chance = (this.chance * 2).toFixed(2);
                break;
                case "/2":
                    this.chance = (this.chance / 2).toFixed(2);
                break;
            }
        },
        updateResult() {
            if(this.chance < 1) return;
            this.minRange.max = Math.floor((this.chance / 100) * 999999);
            this.middleRange.min = Math.floor((100 - this.chance) * 10000 / 2);
            this.middleRange.max = Math.floor(((100 - this.chance) * 10000 / 2) + (this.chance / 100 * 999999));
            this.maxRange.min = 999999 - Math.floor((this.chance / 100) * 999999);
            this.result = Number(((100 / this.chance) * this.bet).toFixed(2));
        },
        validateBet() {
            if (this.bet > 1000000) {
                this.bet = 1000000;
            }

            this.bet = this.bet.toString();
            this.bet = this.bet.replace(/[,]/g, '.').replace(/[^\d,.]*/g, '').replace(/([,.])[,.]+/g, '$1').replace(/^[^\d]*(\d+([.,]\d{0,2})?).*$/g, '$1');
        },
        validateChance() {
            if (this.chance > 95) {
                this.chance = 95;
            }

            this.chance = this.chance.toString();
            this.chance = this.chance.replace(/.00/g, '').replace(/[,]/g, '.').replace(/[^\d,.]*/g, '').replace(/([,.])[,.]+/g, '$1').replace(/^[^\d]*(\d+([.,]\d{0,2})?).*$/g, '$1');
        }
    },
    watch: {
        bet: function() {
            this.validateBet();
            this.updateResult();
        },
        chance: function() {
            this.validateChance();
            this.updateResult();
        }
    }
}
</script>

<style scoped>
.dice {
    padding: 32px 57px;
    background: #fff;
    border-radius: 0 0 8px 8px;
}
@media (max-width: 62em) {
    .dice {
        padding: 12px 15px 23px;
    }
}
.dice__row {
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;
}
.dice__col {
    flex: 0 0 30%;
}
.dice__col:nth-child(2) {
    flex: 0 0 250px;
}
@media (max-width: 62em) {
    .dice__col {
        flex: 0 0 48%;
    }
    .dice__col:nth-child(2) {
        order: -1;
        flex: 1 0 100%;
        margin-bottom: 21px;
    }
}
.dice__col_3-cols {
    flex: 0 0 30%;
}
@media (max-width: 62em) {
    .dice__col_3-cols {
        flex: 0 0 48%;
    }
    /* .dice__col_3-cols:nth-child(5) {
        order: 1;
        flex: 1 0 100%;
    } */
}
.dice .notification {
    order: 3;
    margin-top: 17px;
}
.notification {
    display: block;
    padding: 15px 0;
    color: #fff;
    text-align: center;
    align-items: center;
    border-radius: 0.25rem;
    position: relative;
    width: 100%;
}
.notification.error_bet {
    background: linear-gradient(to left, #ff7777, #ff5b6f)!important;
}
.notification.success_bet {
    background: linear-gradient(to right, #0ACB90, #2BDE6D)!important;
}
.dice__group {
    display: flex;
    flex-wrap: wrap;
    border: 1px solid #6f7cad;
    border-radius: 0 0 6px 6px;
    justify-content: space-between;
}
.dice__label {
    font-size: 13px;
    line-height: 15px;
    text-align: center;
    letter-spacing: 0.03em;
    display: inline-block;
    color: #b6b0d7;
    margin-bottom: 6px;
    text-transform: uppercase;
}
.dice__label_normal {
    text-transform: none;
    font-size: 16px;
    line-height: 25px;
}
.dice__amount {
    font-weight: 400;
    font-size: 25px;
    font-family: "Rubik";
    color: #2c3034;
    border: none;
    border-bottom: 1px solid #6f7cad;
    flex: 0 0 100%;
    line-height: 52px;
    width: 100%;
}
.dice__amount,
.dice__btn {
    text-align: center;
    letter-spacing: 0.03em;
}
.dice__btn {
    cursor: pointer;
    flex: 1 0 15%;
    font-weight: 700;
    font-size: 12px;
    line-height: 14px;
    background: transparent;
    color: #9fa6c5;
    height: 33px;
    display: flex;
    align-items: center;
    justify-content: center;
    border: none;
    padding: 0;
}
.dice__btn + .dice__btn {
    border-left: 1px solid #6f7cad;
}
.dice__win {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    padding-top: 9px;
}
.dice__win-amount {
    font-size: 40px;
    line-height: 65px;
    text-align: center;
    font-family: Rubik;
    color: #2c3034;
    font-weight: 400;
}
.dice__distance {
    font-size: 14px;
    line-height: 25px;
    white-space: nowrap;
    text-align: center;
    color: #b9b1d7;
    padding: 15px;
    margin-top: 38px;
}
@media (max-width: 62em) {
    .dice__distance {
        margin-top: 18px;
    }
}
.dice__btn-range {
    background: #2c80ff;
    border-radius: 3px;
    font-size: 14px;
    line-height: 16px;
    text-align: center;
    letter-spacing: 0.03em;
    color: #fff;
    padding: 15px 0;
    width: 100%;
    border: none;
    cursor: pointer;
}
.dice__btn-range:hover {
    opacity: 0.9;
}
.dice__message {
    border-radius: 3px;
    font-size: 14px;
    line-height: 16px;
    text-align: center;
    color: #fff;
    padding: 15px 0;
    width: 100%;
    margin-top: 20px
}
.dice__message.success {
    background: linear-gradient(90deg, #0cbf88, #12ca56)!important;
}
.dice__message.error {
    background: linear-gradient(to left,#F45C43,#EB3349)!important;
}
.dice__check {
    font-size: 14px;
    line-height: 16px;
    text-align: center;
    -webkit-text-decoration-line: underline;
    text-decoration-line: underline;
    flex: 1 1 100%;
    color: #b9b1d7;
    margin: 17px auto 0;
}
.dice__hash {
    width: 100%;
    text-align: center;
    color: #b6b0d7;
    font-size: 12px;
    line-height: 14px;
    word-wrap: break-word;
    display: block;
}
.dice__hash a {
    text-decoration: none;
    color: unset;
}
.dice__hash-title {
    margin-top: 21px;
    margin-bottom: 11px;
    width: 100%;
}
.dice__hash-check,
.dice__hash-title {
    font-size: 13px;
    line-height: 15px;
    display: block;
    text-transform: uppercase;
}
.dice__hash-check {
    margin-top: 11px;
}
</style>
